==> kvision-bootstrap-dialog-4.8.1.jar: kvision-kvision-bootstrap-dialog-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kotlinx-coroutines-core', 'kvision-kvision-bootstrap-js-legacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kotlinx-coroutines-core'), require('kvision-kvision-bootstrap-js-legacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-dialog-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-bootstrap-dialog-js-legacy'.");
    }if (typeof this['kotlinx-coroutines-core'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-dialog-js-legacy'. Its dependency 'kotlinx-coroutines-core' was not found. Please, check whether 'kotlinx-coroutines-core' is loaded prior to 'kvision-kvision-bootstrap-dialog-js-legacy'.");
    }if (typeof this['kvision-kvision-bootstrap-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-dialog-js-legacy'. Its dependency 'kvision-kvision-bootstrap-js-legacy' was not found. Please, check whether 'kvision-kvision-bootstrap-js-legacy' is loaded prior to 'kvision-kvision-bootstrap-dialog-js-legacy'.");
    }root['kvision-kvision-bootstrap-dialog-js-legacy'] = factory(typeof this['kvision-kvision-bootstrap-dialog-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-bootstrap-dialog-js-legacy'], kotlin, this['kotlinx-coroutines-core'], this['kvision-kvision-bootstrap-js-legacy']);
  }
}(this, function (_, Kotlin, $module$kotlinx_coroutines_core, $module$kvision_kvision_bootstrap_js_legacy) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var COROUTINE_SUSPENDED = Kotlin.kotlin.coroutines.intrinsics.COROUTINE_SUSPENDED;
  var CoroutineImpl = Kotlin.kotlin.coroutines.CoroutineImpl;
  var Unit = Kotlin.kotlin.Unit;
  var Modal = $module$kvision_kvision_bootstrap_js_legacy.io.kvision.modal.Modal;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var emptySet = Kotlin.kotlin.collections.emptySet_287e2$;
  var Result = Kotlin.kotlin.Result;
  var intercepted = Kotlin.kotlin.coroutines.intrinsics.intercepted_f9mg25$;
  var CancellableContinuationImpl_init = $module$kotlinx_coroutines_core.kotlinx.coroutines.CancellableContinuationImpl;
  Dialog.prototype = Object.create(Modal.prototype);
  Dialog.prototype.constructor = Dialog;
  function suspendCancellableCoroutine$lambda(closure$block) {
    return function (uCont) {
      var cancellable = new CancellableContinuationImpl_init(intercepted(uCont), 1);
      cancellable.initCancellability();
      closure$block(cancellable);
      return cancellable.getResult();
    };
  }
  function Dialog(caption, closeButton, size, animation, centered, scrollable, escape, classes, init) {
    if (caption === void 0)
      caption = null;
    if (closeButton === void 0)
      closeButton = true;
    if (size === void 0)
      size = null;
    if (animation === void 0)
      animation = true;
    if (centered === void 0)
      centered = false;
    if (scrollable === void 0)
      scrollable = false;
    if (escape === void 0)
      escape = true;
    if (classes === void 0) {
      classes = emptySet();
    }if (init === void 0)
      init = null;
    Modal.call(this, caption, closeButton, size, animation, centered, scrollable, escape, classes);
    this.resultCallback_8be2vx$ = null;
    init != null ? init(this) : null;
  }
  function Dialog$getResult$lambda$lambda(this$Dialog, closure$cont) {
    return function (result) {
      this$Dialog.resultCallback_8be2vx$ = null;
      this$Dialog.hide();
      closure$cont.resumeWith_tl1gpc$(new Result(result));
      return Unit;
    };
  }
  function Dialog$getResult$lambda(this$Dialog) {
    return function (cont) {
      this$Dialog.resultCallback_8be2vx$ = Dialog$getResult$lambda$lambda(this$Dialog, cont);
      this$Dialog.show();
      return Unit;
    };
  }
  function Coroutine$getResult($this, continuation_0) {
    CoroutineImpl.call(this, continuation_0);
    this.exceptionState_0 = 1;
    this.$this = $this;
  }
  Coroutine$getResult.$metadata$ = {
    kind: Kotlin.Kind.CLASS,
    simpleName: null,
    interfaces: [CoroutineImpl]
  };
  Coroutine$getResult.prototype = Object.create(CoroutineImpl.prototype);
  Coroutine$getResult.prototype.constructor = Coroutine$getResult;
  Coroutine$getResult.prototype.doResume = function () {
    do
      try {
        switch (this.state_0) {
          case 0:
            this.state_0 = 2;
            this.result_0 = suspendCancellableCoroutine$lambda(Dialog$getResult$lambda(this.$this))(this);
            if (this.result_0 === COROUTINE_SUSPENDED)
              return COROUTINE_SUSPENDED;
            continue;
          case 1:
            throw this.exception_0;
          case 2:
            this.result_0;
            return this.result_0;
          default:this.state_0 = 1;
            throw new Error('State Machine Unreachable execution');
        }
      } catch (e) {
        if (this.state_0 === 1) {
          this.exceptionState_0 = this.state_0;
          throw e;
        } else {
          this.state_0 = this.exceptionState_0;
          this.exception_0 = e;
        }
      }
     while (true);
  };
  Dialog.prototype.getResult = function (continuation_0, suspended) {
    var instance = new Coroutine$getResult(this, continuation_0);
    if (suspended)
      return instance;
    else
      return instance.doResume(null);
  };
  Dialog.prototype.setResult_11rb$ = function (result) {
    var tmp$;
    (tmp$ = this.resultCallback_8be2vx$) != null ? tmp$(result) : null;
  };
  Dialog.prototype.hide = function () {
    var tmp$;
    (tmp$ = this.resultCallback_8be2vx$) != null ? tmp$(null) : null;
    return Modal.prototype.hide.call(this);
  };
  Dialog.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'Dialog',
    interfaces: [Modal]
  };
  $$importsForInline$$['kotlinx-coroutines-core'] = $module$kotlinx_coroutines_core;
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$modal = package$kvision.modal || (package$kvision.modal = {});
  package$modal.Dialog = Dialog;
  Kotlin.defineModule('kvision-kvision-bootstrap-dialog-js-legacy', _);
  return _;
}));

==> kvision-bootstrap-dialog-5.15.2.jar: kvision-kvision-bootstrap-dialog-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kotlinx-coroutines-core', 'kvision-kvision-bootstrap-js-legacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kotlinx-coroutines-core'), require('kvision-kvision-bootstrap-js-legacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-dialog-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-bootstrap-dialog-js-legacy'.");
    }
    if (typeof this['kotlinx-coroutines-core'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-dialog-js-legacy'. Its dependency 'kotlinx-coroutines-core' was not found. Please, check whether 'kotlinx-coroutines-core' is loaded prior to 'kvision-kvision-bootstrap-dialog-js-legacy'.");
    }
    if (typeof this['kvision-kvision-bootstrap-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-dialog-js-legacy'. Its dependency 'kvision-kvision-bootstrap-js-legacy' was not found. Please, check whether 'kvision-kvision-bootstrap-js-legacy' is loaded prior to 'kvision-kvision-bootstrap-dialog-js-legacy'.");
    }
    root['kvision-kvision-bootstrap-dialog-js-legacy'] = factory(typeof this['kvision-kvision-bootstrap-dialog-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-bootstrap-dialog-js-legacy'], kotlin, this['kotlinx-coroutines-core'], this['kvision-kvision-bootstrap-js-legacy']);
  }
}(this, function (_, Kotlin, $module$kotlinx_coroutines_core, $module$kvision_kvision_bootstrap_js_legacy) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var COROUTINE_SUSPENDED = Kotlin.kotlin.coroutines.intrinsics.COROUTINE_SUSPENDED;
  var CoroutineImpl = Kotlin.kotlin.coroutines.CoroutineImpl;
  var Unit = Kotlin.kotlin.Unit;
  var Modal = $module$kvision_kvision_bootstrap_js_legacy.io.kvision.modal.Modal;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var Result = Kotlin.kotlin.Result;
  var intercepted = Kotlin.kotlin.coroutines.intrinsics.intercepted_f9mg25$;
  var CancellableContinuationImpl_init = $module$kotlinx_coroutines_core.kotlinx.coroutines.CancellableContinuationImpl;
  Dialog.prototype = Object.create(Modal.prototype);
  Dialog.prototype.constructor = Dialog;
  function suspendCancellableCoroutine$lambda(closure$block) {
    return function (uCont) {
      var cancellable = new CancellableContinuationImpl_init(intercepted(uCont), 1);
      cancellable.initCancellability();
      closure$block(cancellable);
      return cancellable.getResult();
    };
  }
  function Dialog(caption, closeButton, size, animation, centered, scrollable, escape, className, init) {
    if (caption === void 0)
      caption = null;
    if (closeButton === void 0)
      closeButton = true;
    if (size === void 0)
      size = null;
    if (animation === void 0)
      animation = true;
    if (centered === void 0)
      centered = false;
    if (scrollable === void 0)
      scrollable = false;
    if (escape === void 0)
      escape = true;
    if (className === void 0)
      className = null;
    if (init === void 0)
      init = null;
    Modal.call(this, caption, closeButton, size, animation, centered, scrollable, escape, className);
    this.resultCallback_8be2vx$ = null;
    init != null ? init(this) : null;
  }
  function Dialog$getResult$lambda$lambda(this$Dialog, closure$cont) {
    return function (result) {
      this$Dialog.resultCallback_8be2vx$ = null;
      this$Dialog.hide();
      closure$cont.resumeWith_tl1gpc$(new Result(result));
      return Unit;
    };
  }
  function Dialog$getResult$lambda(this$Dialog) {
    return function (cont) {
      this$Dialog.resultCallback_8be2vx$ = Dialog$getResult$lambda$lambda(this$Dialog, cont);
      this$Dialog.show();
      return Unit;
    };
  }
  function Coroutine$getResult($this, continuation_0) {
    CoroutineImpl.call(this, continuation_0);
    this.exceptionState_0 = 1;
    this.$this = $this;
  }
  Coroutine$getResult.$metadata$ = {
    kind: Kotlin.Kind.CLASS,
    simpleName: null,
    interfaces: [CoroutineImpl]
  };
  Coroutine$getResult.prototype = Object.create(CoroutineImpl.prototype);
  Coroutine$getResult.prototype.constructor = Coroutine$getResult;
  Coroutine$getResult.prototype.doResume = function () {
    do
      try {
        switch (this.state_0) {
          case 0:
            this.state_0 = 2;
            this.result_0 = suspendCancellableCoroutine$lambda(Dialog$getResult$lambda(this.$this))(this);
            if (this.result_0 === COROUTINE_SUSPENDED)
              return COROUTINE_SUSPENDED;
            continue;
          case 1:
            throw this.exception_0;
          case 2:
            this.result_0;
            return this.result_0;
          default:
            this.state_0 = 1;
            throw new Error('State Machine Unreachable execution');
        }
      } catch (e) {
        if (this.state_0 === 1) {
          this.exceptionState_0 = this.state_0;
          throw e;
        } else {
          this.state_0 = this.exceptionState_0;
          this.exception_0 = e;
        }
      }
     while (true);
  };
  Dialog.prototype.getResult = function (continuation_0, suspended) {
    var instance = new Coroutine$getResult(this, continuation_0);
    if (suspended)
      return instance;
    else
      return instance.doResume(null);
  };
  Dialog.prototype.setResult_11rb$ = function (result) {
    var tmp$;
    (tmp$ = this.resultCallback_8be2vx$) != null ? tmp$(result) : null;
  };
  Dialog.prototype.hide = function () {
    var tmp$;
    (tmp$ = this.resultCallback_8be2vx$) != null ? tmp$(null) : null;
    return Modal.prototype.hide.call(this);
  };
  Dialog.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'Dialog',
    interfaces: [Modal]
  };
  $$importsForInline$$['kotlinx-coroutines-core'] = $module$kotlinx_coroutines_core;
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$modal = package$kvision.modal || (package$kvision.modal = {});
  package$modal.Dialog = Dialog;
  Kotlin.defineModule('kvision-kvision-bootstrap-dialog-js-legacy', _);
  return _;
}));
